pub struct Error { /* private fields */ }Expand description
Client errors
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_connect(&self) -> bool
pub fn is_connect(&self) -> bool
Returns true if this was an error from Connect.
Sourcepub fn connect_info(&self) -> Option<&Connected>
pub fn connect_info(&self) -> Option<&Connected>
Returns the info of the client connection on which this error occurred.